@@ -206,7 +206,7 @@ def send_message(
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def set_webhook(token, url=None, certificate=None, max_connections=None, allowed_updates=None):
+def set_webhook(token, url=None, certificate=None, max_connections=None, allowed_updates=None, ip_address=None, timeout=None):
     method_url = r'setWebhook'
     payload = {
         'url': url if url else "",
@@ -218,17 +218,28 @@ def set_webhook(token, url=None, certificate=None, max_connections=None, allowed
         payload['max_connections'] = max_connections
     if allowed_updates is not None:  # Empty lists should pass
         payload['allowed_updates'] = json.dumps(allowed_updates)
+    if ip_address is not None:       # Empty string should pass
+        payload['ip_address'] = ip_address
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload, files=files)
 
 
-def delete_webhook(token):
+def delete_webhook(token, drop_pending_updates=None, timeout=None):
     method_url = r'deleteWebhook'
-    return _make_request(token, method_url)
+    payload = {}
+    if drop_pending_updates is not None:  # None / True / False
+        payload['drop_pending_updates'] = drop_pending_updates
+    if timeout:
+        payload['connect-timeout'] = timeout
+    return _make_request(token, method_url, params=payload)
 
 
-def get_webhook_info(token):
+def get_webhook_info(token, timeout=None):
     method_url = r'getWebhookInfo'
     payload = {}
+    if timeout:
+        payload['connect-timeout'] = timeout
     return _make_request(token, method_url, params=payload)
 
 
@@ -703,7 +714,7 @@ def kick_chat_member(token, chat_id, user_id, until_date=None):
 def unban_chat_member(token, chat_id, user_id, only_if_banned):
     method_url = 'unbanChatMember'
     payload = {'chat_id': chat_id, 'user_id': user_id}
-    if only_if_banned:
+    if only_if_banned is not None:  # None / True / False
         payload['only_if_banned'] = only_if_banned
     return _make_request(token, method_url, params=payload, method='post')
 
@@ -715,25 +726,27 @@ def restrict_chat_member(
         can_add_web_page_previews=None, can_change_info=None,
         can_invite_users=None, can_pin_messages=None):
     method_url = 'restrictChatMember'
-    payload = {'chat_id': chat_id, 'user_id': user_id}
+    permissions = {}
     if until_date is not None:
-        payload['until_date'] = until_date
+        permissions['until_date'] = until_date
     if can_send_messages is not None:
-        payload['can_send_messages'] = can_send_messages
+        permissions['can_send_messages'] = can_send_messages
     if can_send_media_messages is not None:
-        payload['can_send_media_messages'] = can_send_media_messages
+        permissions['can_send_media_messages'] = can_send_media_messages
     if can_send_polls is not None:
-        payload['can_send_polls'] = can_send_polls
+        permissions['can_send_polls'] = can_send_polls
     if can_send_other_messages is not None:
-        payload['can_send_other_messages'] = can_send_other_messages
+        permissions['can_send_other_messages'] = can_send_other_messages
     if can_add_web_page_previews is not None:
-        payload['can_add_web_page_previews'] = can_add_web_page_previews
+        permissions['can_add_web_page_previews'] = can_add_web_page_previews
     if can_change_info is not None:
-        payload['can_change_info'] = can_change_info
+        permissions['can_change_info'] = can_change_info
     if can_invite_users is not None:
-        payload['can_invite_users'] = can_invite_users
+        permissions['can_invite_users'] = can_invite_users
     if can_pin_messages is not None:
-        payload['can_pin_messages'] = can_pin_messages
+        permissions['can_pin_messages'] = can_pin_messages
+    permissions_json = json.dumps(permissions)
+    payload = {'chat_id': chat_id, 'user_id': user_id, 'permissions': permissions_json}
     return _make_request(token, method_url, params=payload, method='post')
 
 
@@ -818,7 +831,9 @@ def set_my_commands(token, commands):
 
 def set_chat_description(token, chat_id, description):
     method_url = 'setChatDescription'
-    payload = {'chat_id': chat_id, 'description': description}
+    payload = {'chat_id': chat_id}
+    if description is not None:  # Allow empty strings
+        payload['description'] = description
     return _make_request(token, method_url, params=payload, method='post')
 
 
@@ -830,9 +845,17 @@ def pin_chat_message(token, chat_id, message_id, disable_notification=None):
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def unpin_chat_message(token, chat_id):
+def unpin_chat_message(token, chat_id, message_id):
     method_url = 'unpinChatMessage'
     payload = {'chat_id': chat_id}
+    if message_id:
+        payload['message_id'] = message_id
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def unpin_all_chat_messages(token, chat_id):
+    method_url = 'unpinAllChatMessages'
+    payload = {'chat_id': chat_id}
     return _make_request(token, method_url, params=payload, method='post')
 
 
